@@ -1,13 +1,13 @@
 ##' Cross type K function using homotypic and heterotypic case types
 ##'
-##' A wrapper function of the \link[spatstat.core]{Kcross} function from the \pkg{spatstat.core} package (Baddeley et al. 2016) that takes epidemiological data used by \pkg{IDSpatialStats} functions and calculates the cross type K-function based on user defined case type homology
+##' A wrapper function of the \link[spatstat.explore]{Kcross} function from the \pkg{spatstat.explore} package (Baddeley et al. 2016) that takes epidemiological data used by \pkg{IDSpatialStats} functions and calculates the cross type K-function based on user defined case type homology
 ##'
 ##' @param epi.data a three-column numerical matrix that contains coordinates (\code{x} and \code{y}) for each case and information on case type (e.g. genotype or serotype). First two columns must be \code{x} and \code{y}
 ##' @param type an integer giving the column that contains information on case type. Must be an integer or a character
 ##' @param hom a scalar or vector giving the homotypic case type(s). Equivalent to the 'j' point type used in the cross K function. Must be an integer or character
 ##' @param het a scalar or vector giving the heterotypic case type(s). Equivalent to the 'i' point type used in the cross K function. The default is \code{NULL}, which uses any case type not defined in the \code{hom} argument as heterotypic. Must be an integer or a character
 ##' @param r a numeric vector giving the spatial distances
-##' @param correction type of edge correction to be applied (default set to 'none'). See the \link[spatstat.core]{Kcross} function in the \pkg{spatstat.core} package for more details
+##' @param correction type of edge correction to be applied (default set to 'none'). See the \link[spatstat.explore]{Kcross} function in the \pkg{spatstat.explore} package for more details
 ##' 
 ##' @return a data frame with a minimum of three columns giving the radius (\code{r}), the theoretical value of the K function for a Poisson process (\code{theo}), and value of the K function evaluated at radius \code{r}. The column name gives the type of edge correction used 
 ##'
@@ -59,19 +59,19 @@ get.cross.K <- function(epi.data, # matrix containing xy coordinates and case ty
                                         marks=as.factor(ppp.dat[,ncol(ppp.dat)]),
                                         check=FALSE)
 
-     return(as.data.frame(spatstat.core::Kcross(X=epi.data.ppp, i=0, j=1, r=r, correction=correction)))
+     return(as.data.frame(spatstat.explore::Kcross(X=epi.data.ppp, i=0, j=1, r=r, correction=correction)))
 }
 
 ##' Cross type Pair Correlation Function using homotypic and heterotypic case types
 ##'
-##' A wrapper function of the \link[spatstat.core]{pcf} function from the \pkg{spatstat.core} package (Baddeley et al. 2016) that takes epidemiological data used by \pkg{IDSpatialStats} functions and calculates the cross type Pair Correlation Function based on user defined case type homology
+##' A wrapper function of the \link[spatstat.explore]{pcf} function from the \pkg{spatstat.explore} package (Baddeley et al. 2016) that takes epidemiological data used by \pkg{IDSpatialStats} functions and calculates the cross type Pair Correlation Function based on user defined case type homology
 ##'
 ##' @param epi.data a three-column numerical matrix that contains coordinates (\code{x} and \code{y}) for each case and information on case type (e.g. genotype or serotype). First two columns must be \code{x} and \code{y}
 ##' @param type an integer giving the column that contains information on case type. Must be an integer or a character
 ##' @param hom a scalar or vector giving the homotypic case type(s). Equivalent to the 'j' point type used in the cross K function. Must be an integer or character
 ##' @param het a scalar or vector giving the heterotypic case type(s). Equivalent to the 'i' point type used in the cross K function. The default is \code{NULL}, which uses any case type not defined in the \code{hom} argument as heterotypic. Must be an integer or a character
 ##' @param r a numeric vector giving the spatial distances
-##' @param correction type of edge correction to be applied (default set to 'none'). See the \link[spatstat.core]{pcf} function in the \pkg{spatstat.core} package for more details
+##' @param correction type of edge correction to be applied (default set to 'none'). See the \link[spatstat.explore]{pcf} function in the \pkg{spatstat.explore} package for more details
 ##' 
 ##' @return a data frame with two columns giving the radius \code{r}, the theoretical value of the Pair Correlation Function for a Poisson process (\code{theo}), and value of the Pair Correlation Function \code{pcf}
 ##'
@@ -123,6 +123,6 @@ get.cross.PCF <- function(epi.data, # matrix containing xy coordinates and case
                                         marks=as.factor(ppp.dat[,ncol(ppp.dat)]),
                                         check=FALSE)
      
-     return(as.data.frame(spatstat.core::pcf(spatstat.core::pcf(X=epi.data.ppp, i=0, j=1, r=r, correction=correction), spar=0.8, method='c')))
+     return(as.data.frame(spatstat.explore::pcf(spatstat.explore::pcf(X=epi.data.ppp, i=0, j=1, r=r, correction=correction), spar=0.8, method='c')))
 }
 
